@@ -12,6 +12,10 @@ from .augmenting import (
     extend,
 )
 
+from .generating import (
+    one,
+)
+
 from .parsing import (
     range_from_text,
     expand_numbered_list,
@@ -33,6 +37,7 @@ from .selecting import (
     take_until_inclusive,
     take_between_inclusive,
     take_between_inclusive_values,
+    single,
     skip_while,
 )
 
@@ -57,6 +62,7 @@ __all__ = [
     "first_matching",
     "join_with",
     "nth_matching",
+    "one",
     "prepend",
     "prepend_if",
     "range_from_text",
@@ -76,5 +82,6 @@ __all__ = [
     "take_until_inclusive",
     "take_between_inclusive",
     "take_between_inclusive_values",
+    "single",
     "skip_while",
 ]
